%%  This is file `SBU-Proposal.cls',
%%	by: Ali Salehi, alisalehi076@gmail.com
%%  https://ccg.sbu.ac.ir/people/ali-salehi
%%	Ver 1.0.0, January 2025
%% https://github.com/iamalisalehi/sbu-proposal

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SBU-Proposal}
[26/1/2025 v1.0.0
Persian proposal document class in XeLaTeX for Shahid Beheshti University projects/theses/dissertations]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[a4paper,oneside,12pt]{article}

%%%%%%%%%%%%%%%%%%%%%

\def\university#1{\gdef\@university{#1}}
\def\department#1{\gdef\@department{#1}}
\def\degree#1{\gdef\@degree{#1}}
\def\thesisdate#1{\gdef\@thesisdate{#1}}

%%%%%%%%%%%%%%%%%%%%%

\newcommand{\firstsupervisor}[1]{\def\@firstsupervisor{#1}}
\newcommand{\secondsupervisor}[1]{\def\@secondsupervisor{#1}}
\newcommand{\firstadvisor}[1]{\def\@firstadvisor{#1}}
\newcommand{\secondadvisor}[1]{\def\@secondadvisor{#1}}

%%%%%%%%%%%%%%%%%%%%%

\def\name#1{\gdef\@name{#1}}
\def\surname#1{\gdef\@surname{#1}}
\def\keywords#1{\gdef\@keywords{#1}}
\def\latinkeywords#1{\gdef\@\latinkeywords{#1}}
\def\fa-abstract#1{\gdef\@fa-abstract{#1}}
\def\faculty#1{\gdef\@faculty{#1}}
\def\subject#1{\gdef\@subject{#1}}

%%%%%%%%%%%%%%%%%%%%%

\def\field#1{\gdef\@field{#1}}
\def\department#1{\gdef\@department{#1}}
\def\projectLabel#1{\gdef\@projectLabel{#1}}

%%%%%%%%%%%%%%%%%%%%%

\def\latintitle#1{\gdef\@latintitle{#1}}
\def\latinkeywords#1{\gdef\@latinkeywords{#1}}

%%%%%%%%%%%%%%%%%%%%%

% پیشنهاده ارشد
\projectLabel{پیشنهاده پایان‌نامه کارشناسی ارشد}
\degree{کارشناسی ارشد}

%%%%%%%%%%%%%%%%%%%%%

%   Reduce the margin of the summary:
\def\changemargin#1#2{\list{}{\rightmargin#2\leftmargin#1}\item[]}
\let\endchangemargin=\endlist 

%   Generate the environment for the abstract:
\newcommand\summaryname{}
\newenvironment{Abstract}%
{\small\begin{center}%
		\bfseries{\summaryname} \end{center}}

%%%%%%%%%%%%%%%%%%%%%

% صفحه اول پیشنهاده
\newcommand{\firstPage}{
	\begin{titlepage}
		\topmargin=-30pt
		\vspace{-10mm}
		\centerline{{\includegraphics[width=4cm]{sbu_logo}}}
		\vspace{2mm}
		\centerline{\large \bf \@university} 
		\vskip 0.5cm
		{\large\bfseries\@faculty\space}
		\vskip 1cm
		%nkhComment: in case the title is too large

		{\large\bfseries{\@projectLabel\ \ \@subject}
			\vspace{3mm}
			\\گرایش \@field
		}
		\par
		\vskip 10mm
		
		\linespread{1.2}
		{\huge \titlefont \@title \par}
		
		\vskip 15mm
		
		\linespread{1.2}
		{%\latintitlefont 
			\huge
			\bf \lr{\@latintitle} \par}
		
		\vskip 15mm
		
		{\large\by}%\par
		\\ \vskip 0.45cm
		{\large\bfseries{\large\bfseries \@name\ \ \@surname}}
		%\par
		\vskip 10mm
		\large
		{
			\ifx\@firstsupervisor\undefined%
			\ifx\@secondsupervisor\undefined%
			\else
			\fi
			\else
			\ifx\@secondsupervisor\undefined%
			استاد راهنما:
			\\ \vskip 0.35cm
			{\large\bfseries
				\@firstsupervisor}
			\else
			\large
			اساتادان راهنما
			\\ \vskip 0.35cm
			{\large\bfseries \@firstsupervisor{} و \@secondsupervisor}
			\fi\fi}
		\par\large
		{\ifx\@firstadvisor\undefined%
			\ifx\@secondadvisor\undefined%
			\else\fi
			\else
			\ifx\@secondadvisor\undefined%
			\vskip 1cm
			استاد مشاور
			\\ \vskip 0.35cm
			{\large\bfseries
				\@firstadvisor}
			\else
			
			\large
			\vskip 1cm
			استادان مشاور
			\\ \vskip 0.4cm
			{\large\bfseries\@firstadvisor{} و \@secondadvisor}
			\fi\fi}
		
		\par
		\vskip 10mm
		%\vfill
		{\large \@thesisdate}
		%\vfill
	\end{titlepage}%
} % end of firstPage

\def\titlepage{\newpage\centering
	\thispagestyle{empty}
	\parindent 0pt \parskip 10pt plus 1fil minus 1fil
	\def\baselinestretch{1}\@normalsize\vbox to \vsize\bgroup\vbox to 9in\bgroup}
\def\endtitlepage{\par\kern 0pt\egroup\vss\egroup\newpage}

%%%%%%%%%%%%%%%%%%%%%
% نوع طرح
\newcommand{\proposalPage}[1]{
	\newpage
	\thispagestyle{plain}
	\vskip 15mm
	{\noindent\bfseries \large نوع طرح:~
		\ifstrequal{#1}{بنیادی}{
			#1 $\blacksquare$
		}
		{
			بنیادی $\square$~
		}
		\ifstrequal{#1}{کاربردی}{
			#1 $\blacksquare$
		}
		{
			کاربردی $\square$~
		}
		\ifstrequal{#1}{توسعه‌ای}{
			#1 $\blacksquare$
		}
		{
			توسعه‌ای $\square$~
		}
		\ifstrequal{#1}{اولویت محور}{
			#1 $\blacksquare$
		}
		{
			اولویت محور $\square$~
		}
		\ifstrequal{#1}{تقاضا محور}{
			#1 $\blacksquare$
		}
		{
			تقاضا محور $\square$~
		}
	}
	\vspace{5mm}
	\par
	\noindent
\textbf{- پژوهش بنیادی}:
 پژوهشی است كه به منظور گسترش و پیشبرد مرزهای دانش، یا ایجاد زمینه علمی برای حل مسائل مرتبط و بدون در نظر گرفتن استفاده عملی خاص برای كاربرد آن انجام میشود.
	\par
	\noindent
\textbf{- پژوهش كاربردی}:
 پژوهشی است كه استفاده عملی خاصی برای نتایج آن منظور می‌شود و غالباً تركیبی از جنبه‌های نظری و تجربی است.
	\par
	\noindent
\textbf{- پژوهش توسعه‌ای}:
 هرگونه فعالیت منظم مبتنی بر دانش کنونی که به منظور تولید مواد، فرآوردها، ابزار، فرایندها و یا به منظور توصیف، طبقه‌بندی و به‌کارگیری روش‌های جدید بهکرد آنها صورت می‌گیرد.
	\par
	\noindent
\textbf{- طرح اولویت محور}:
 طرحی پژوهشی است كه بر اساس یكی از اولویتهای پژوهشی كه در اسناد رسمی علم و فناوری كشور مطرح شده است، انجام می شود.
	\par
	\noindent
\textbf{- طرح تقاضا محور}:
 طرحی پژوهشی است كه بر اساس نیاز صنعت یا سازمان و در قالب قرارداد بین مؤسسه علمی و صنعت/سازمان مربوطه انجام می‌شود.
	\par
}
%%%%%%%%%%%%%%%%%%%%%


% صفحه چکیده
\newcommand\abstractPage
{
	\newpage
	\thispagestyle{plain}
	\vskip 15mm
	{\noindent\bfseries \hfil \large چکیده}
	\vspace{5mm}
	\par
	\noindent
	\@fa-abstract
	\vspace{8mm}
	\par
	\noindent
	\ifdefined\@keywords
	{
		\textbf{واژگان کلیدی:} 
		\@keywords
	}
	\fi
	\par
	\noindent
	\vspace{8mm}
	\begin{LTR}
	\ifdefined\@latinkeywords
	{
		\lr{
			\textbf{Keywords:} 
			\@latinkeywords
		}
	}
	\end{LTR}
\fi
	\newpage
}

%%%%%%%%%%%%%%%%%%%%%

% صفحه پیشگفتار
\newcommand\prefacePage
{
	\newpage
	\thispagestyle{plain}
	\vskip 15mm
	{\noindent\bfseries \hfil \large پیشگفتار}
	\vspace{5mm}
	\par
	\noindent
	\@pish
	\vspace{8mm}
	\par
	\noindent
	\ifdefined\@keywords
	\fi
	\newpage
}

%%%%%%%%%%%%%%%%%%%%%

\def\by{نگارنده:}

\def\cleardoublepage{\clearpage\if@twoside \ifodd\c@page\else
	\hbox{}
	\thispagestyle{empty}
	\newpage
	\if@twocolumn\hbox{}\newpage\fi\fi\fi}

%%%%%%%%%%%%%%%%%%%%%

% Commands

%تنظیم حاشیه صفحات
\usepackage[top=35mm, bottom=25mm, left=25mm, right=25mm]{geometry}
\usepackage{lscape}


\usepackage[bottomtitles]{titlesec} % ایجاد فاصله بین عناوین و خط مطلب بعدی
\usepackage{caption}
\usepackage{subcaption}
\usepackage[nottoc,numbib]{tocbibind} % اضافه کردن مراجع به فهرست مطالب

\usepackage[raggedright]{sidecap}
\usepackage[svgnames]{xcolor}
\usepackage{colortbl}
\usepackage{fontspec}
\usepackage{setspace}
\usepackage{minted}

\titleformat{\section}
{\normalfont\Large\bfseries}{\thesection}{1em}{}
\titleformat{\subsection}
{\normalfont\large\bfseries}{\thesubsection}{1em}{}
\titleformat{\subsubsection}
{\normalfont\normalsize\bfseries}{\thesubsubsection}{1em}{}
\titleformat{\paragraph}[runin]
{\normalfont\normalsize\bfseries}{\theparagraph}{1em}{}
\titleformat{\subparagraph}[runin]
{\normalfont\normalsize\bfseries}{\thesubparagraph}{1em}{}

\titlespacing\section{0pt}{22pt plus 4pt minus 2pt}{0pt plus 2pt minus 2pt}
\titlespacing\subsection{0pt}{18pt plus 4pt minus 2pt}{0pt plus 2pt minus 2pt}
\titlespacing\subsubsection{0pt}{16pt plus 4pt minus 2pt}{0pt plus 2pt minus 2pt}

\usepackage{indentfirst}
\usepackage{multirow}
% در ورژن جدید زی‌پرشین برای تایپ متن‌های ریاضی، این سه بسته، حتماً باید فراخوانی شود
\usepackage{amsthm,amssymb,amsmath}
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%تنطیمات خط بالایی صفحه
\usepackage{fancyhdr}
\pagestyle{fancy}
\setlength{\headheight}{15pt}

\lhead{}
% Length to control the \fancyheadoffset and the calculation of \headline
% simultaneously
\newlength\FHoffset
\setlength\FHoffset{0cm} %بیشتر بودن خط بالا از حاشیه کناری صفحه

\addtolength\headwidth{2\FHoffset}

\fancyheadoffset{\FHoffset}

% these lengths will control the headrule trimming to the left and right 
\newlength\FHleft
\newlength\FHright

% here the trimmings are controlled by the user
\setlength\FHleft{1cm}
\setlength\FHright{0cm}

\lhead{\thepage} % نمایش شماره صفحه در سمت راست هدر
\rhead{\leftmark}
\cfoot{} % نمایش ندادن شماره صفحه در پایین صفحه

% The new definition of headrule that will take into acount the trimming(s)
\newbox\FHline
\setbox\FHline=\hbox{\hsize=\paperwidth%
	\hspace*{\FHleft}%
	\rule{\dimexpr\headwidth-\FHleft-\FHright\relax}{\headrulewidth}\hspace*{\FHright}%
}

\linespread{2} % تنظیم فاصله خطوط به 1.5

%%%%%%%%%%%%%%%%%%%%%

\usepackage[bottom,hang,flushmargin]{footmisc} % شروع شماره زیرنویس ها از ۱ در هر صفحه و انتقال به پایین
\usepackage{zref-perpage}
\zmakeperpage{footnote}
\setlength{\skip\footins}{12pt} %تنظیم فاصله متن تا خط زیرنویس


% بسته‌ و دستوراتی برای ایجاد لینک‌های رنگی با امکان جهش
\usepackage[pagebackref=false,colorlinks,linkcolor=blue,citecolor=blue]{hyperref}
% چنانچه قصد پرینت گرفتن نوشته خود را دارید، خط بالا را غیرفعال و  از دستور زیر استفاده کنید چون در صورت استفاده از دستور زیر‌‌، 
% لینک‌ها به رنگ سیاه ظاهر خواهند شد که برای پرینت گرفتن، مناسب‌تر است
%\usepackage[hidelinks,pagebackref=false]{hyperref}
%\usepackage{cleveref}


\setcounter{tocdepth}{3}
% نمایش \subsubsection در فهرست مطالب
%\part = -1, chapter = 0, \section = 1, subsection = 2, \subsubsection = 3, \paragraph = 4, \subparagraph = 5
%\setcounter{secnumdepth}{3}% Number \subsubsection این که بیشتر از سه سطح شماره گذاری داشته باشیم خوانایی را کاهش می‌دهد.

\usepackage{bookmark} % برای اضافه کردن لینک‌های کنار pdf و همینطور لینک شدن رفرنس و زیرنویس‌ها

\input{config}

\usepackage[font=small,labelfont=bf,skip=4pt]{caption}
\usepackage{graphicx}
%\usepackage{subfig}
\usepackage{longtable}
\usepackage{enumitem}

\setlength{\emergencystretch}{4pt} %جلوگیری از نشکستن خطوط

\usepackage[extrafootnotefeatures]{xepersian}
\settextfont[BoldFont={IRLotusICEE_Bold.ttf}, BoldItalicFont={IRLotusICEE_BoldIranic.ttf}, ItalicFont={IRLotusICEE_Iranic.ttf},Scale=1.2]{IRLotusICEE.ttf}%{IRZar.ttf}

\setlatintextfont[Scale=1]{Times New Roman}

%%%%%%%%%%%%%%%%%%%%%%%%%%
%\setdigitfont[Scale=1.2]{IRLotusICEE.ttf}
%%%%%%%%%%%%%%%%%%%%%%%%%%
% تعریف قلم های فارسی و انگلیسی اضافی برای استفاده در بعضی از قسمت‌های متن
\defpersianfont\titlefont[Scale=1]{XB Titre.ttf}
\setiranicfont[Scale=1.3]{IRLotusICEE_Iranic.ttf}				% ایرانیک، خوابیده به چپ
\setmonofont[Scale=0.9]{AzarMehrMonospaced}

% تنظیم فونت یونانی
\deflatinfont\Greekfont[Script=Greek]{CMU Serif}
\DeclareTextFontCommand\textgreek{\Greekfont}

\renewcommand\listfigurename{فهرست نمودارها}
\renewcommand\listtablename{فهرست جدول‌ها}

\usepackage{notoccite} %جلوگیری از شماره‌گزاری تصاویر در فهرست
\usepackage{cite} % تبدیل ارجاعات به جای چند عدد به محدوده مثلا [10-13]

% ایجاد امکان ساخت پیوست قبل از مراجع
\makeatletter
\newcounter{savesection}
\newcounter{apdxsection}
\renewcommand\appendix{\par
	\setcounter{savesection}{\value{section}}%
	\setcounter{section}{\value{apdxsection}}%
	\setcounter{subsection}{0}%
	\gdef\thesection{\@Alph\c@section}}
\newcommand\unappendix{\par
	\setcounter{apdxsection}{\value{section}}%
	\setcounter{section}{\value{savesection}}%
	\setcounter{subsection}{0}%
	\gdef\thesection{\@arabic\c@section}}
\makeatother

% بسته‌ای برای رسم نمودار


%% Distributable under the LaTeX Project Public License,
%% version 1.3c or higher (your choice). The latest version of
%% this license is at: http://www.latex-project.org/lppl.txt
%% 
%% 
%% Special thanks to Vafa Khalighi for xepersian package.
%%
%% End of file `SBU-Proposal.cls'.

